pub enum PermissionConfigError {
MissingDefaultGroup(String),
MissingRequiredGroup(String),
MissingInheritedGroup {
group: String,
inherited: String,
},
InheritedGroupCycle(Vec<String>),
InvalidPermissionExpression {
group: String,
source: PermissionRuleExpressionError,
},
InvalidMetadataExpression {
group: String,
source: PermissionMetadataExpressionError,
},
InvalidGroupName {
group: String,
source: PermissionKeyError,
},
}Expand description
Invalid permission group configuration.
Variants
MissingDefaultGroup(String)
A default group does not exist in the group map.
MissingRequiredGroup(String)
A built-in required group does not exist in the group map.
MissingInheritedGroup
A group inherits a group that does not exist.
InheritedGroupCycle(Vec<String>)
Group inheritance contains a cycle, including the repeated final name.
InvalidPermissionExpression
A group contains an invalid permission rule expression.
Fields

source: PermissionRuleExpressionErrorParse error.
InvalidMetadataExpression
A group contains an invalid metadata expression.
Fields

source: PermissionMetadataExpressionErrorParse error.
InvalidGroupName
A group name is not a valid command-usable segment.