pub enum PermissionRuleContextError {
InvalidDomain(String),
InvalidValue(String),
DuplicateDomain,
DuplicateWorld,
DuplicateCustomKey(PermissionContextKey),
WorldDomainMismatch {
domain: String,
world_domain: String,
},
}Expand description
Invalid rule-side or active permission context.
Variants
InvalidDomain(String)
A domain name is not a valid identifier namespace.
InvalidValue(String)
A custom value cannot be represented by the expression syntax.
DuplicateDomain
One chain binds two different domains.
DuplicateWorld
One chain binds two different loaded worlds.
DuplicateCustomKey(PermissionContextKey)
One custom key is bound to two different values.
WorldDomainMismatch
A world identifier and explicit domain name disagree.